(* ::Package:: *)

(* ::Title:: *)
(*Ancillary files for Three-loop QCD-electroweak corrections to Higgs gluon fusion*)


(* ::Text:: *)
(*In this ancillary file it is possible to find, opening the various Sections, the Master Intergals, the Canonical Functions and their differential equations, and the Amplitude.*)
(**)
(*We suggest to first read through the file, and then select the parts of interest.*)


(* ::Section::Closed:: *)
(*Master Integrals*)


(* ::Text:: *)
(*The MIs in MIList are provided in the same order as in Appendix B in the paper.*)
(*The MIs are written using Reduze notation*)


INT{"EW3TOP",t,ID,r,s,LIST_PROPAGATORS}


(* ::Text:: *)
(*where:*)
(*EW3TOP is the family of denominators. The families of denominators are listed in Appendix A in the paper. Specifically: EW3PP is topology PP, EW3NA is topology NA, EW3NB is topology NB;*)
(*t is the number of propagators;*)
(*ID is the unique number associated to the graph of the MI;*)
(*r is the sum of the positive exponents;*)
(*s is the sum of the negative exponents;*)
(*LIST_PROPAGATORS is a list of the powers to which each denominator (listed in the same order as in Table 2, Appendix A in the paper) is raised in the denominator.*)


SetDirectory[NotebookDirectory[]];
MIList=Import["Repository/MIList.m"];


(* ::Section::Closed:: *)
(*Canonical Functions, Differential Equations and Integration Constants*)


(* ::Subsection::Closed:: *)
(*Canonical Functions*)


(* ::Subsubsection::Closed:: *)
(*Canonical functions in terms of MIs*)


(* ::Text:: *)
(*CFMI is a list of substitutions giving the expressions of the element of the canonical basis in terms of the MIs defined in Section "Master Integrals".*)


SetDirectory[NotebookDirectory[]];
CFMI=Import["Repository/Canonical_Functions_as_MIs.m"];


(* ::Subsubsection::Closed:: *)
(*Canonical functions in terms of GPLs*)


(* ::Text:: *)
(*CF is a list of substitutions giving the expressions of the elements of the canonical basis in terms of GPLs up to order \[Epsilon]^6.*)


SetDirectory[NotebookDirectory[]];
CF=Join[Import["Repository/Canonical_Functions_GPL_1_80.m"],Import["Repository/Canonical_Functions_GPL_81_106.m"]];


(* ::Subsection::Closed:: *)
(*Differential Equations*)


(* ::Text:: *)
(*CFMat is a matrix.*)


SetDirectory[NotebookDirectory[]];
CFMat=Import["Repository/Matrix_of_Coefficients.m"];


(* ::Text:: *)
(*CFMat is related to MatCoeff (the matrix of coefficients of the differential system satisfied by the canonical basis given above) via the relation*)


MatCoeff=\[Epsilon] D[CFMat,y];


(* ::Text:: *)
(*CFMat has already the right choice of signs for the arguments of the Logs to be real in 0<y<1 (s<0).*)


(* ::Subsection::Closed:: *)
(*Integration Constants (obtained through Large-Mass Expansion)*)


(* ::Text:: *)
(*IntCon is a list of substitutions for the integration constants of the form Int[MI_number,\[Epsilon]_order].*)


SetDirectory[NotebookDirectory[]];
IntCon=Import["Repository/Constants_of_Integration.m"];


(* ::Section::Closed:: *)
(*Form Factor*)


(* ::Subsection::Closed:: *)
(*LO finite part*)


(* ::Text:: *)
(*FPLO is a list of substitutions giving the finite part of ALO, as defined in Eq.(6.5) in the paper.*)


SetDirectory[NotebookDirectory[]];
FPLO=Import["Repository/Finite_Part_A_LO.m"];


(* ::Subsection::Closed:: *)
(*NLO finite part*)


(* ::Text:: *)
(*FPVNLO is a list of substitutions giving the UV-renormalized IR-subtracted quantity ANLOfin, as defined in Eq.(6.5) in the paper.*)
(*This expression features Log[s/\[Mu]\[Mu]^2], with the prescription s->s+I 0, where s is the center of mass energy (in this case s=mH^2), and \[Mu]\[Mu] is the regularization scale. The expression  is valid for positive arguments of the logarithms (Minkowski region). For negative arguments (Euclidean region) one must pay attention to the prescription used to generate the imaginary part. Mathematica assignes by default a prescription +I 0, therefore the results should be consistent.*)


SetDirectory[NotebookDirectory[]];
FPVNLO=Import["Repository/Finite_Part_A_NLO_fin.m"];


(* ::Subsection::Closed:: *)
(*Values presented in the paper*)


(* ::Text:: *)
(*To obtain the values presented in Eq.(6.8) of the paper, a routine to evaluate GPLs of the form G[a1,a2,...,an,y] is required.*)
(*To start, load the function TRASF and the expressions FPLO and FPVNLO.*)
(*WARNING: variables r, y, Nc, Nf, s and \[Mu]\[Mu] will be cleared.*)


ClearAll[r,y,Nc,Nf,s,\[Mu]\[Mu]];


TRASF[expr_]:=Module[{tmp,list1,list2,tmp2,x},
tmp=(expr//Expand)/.G[list1__,y]->G[Join[list1,{y}]];
tmp=tmp/.G[{list2__}]->G[list2];
tmp=tmp//.G[r,b__]:>(G[r1,b]+G[r2,b]);
tmp=tmp//.G[a__,r,b__]:>(G[a,r1,b]+G[a,r2,b]);
tmp2=tmp//.G[a__,x]:>G[a,y];
Return[tmp2]
];
r1=1/2+I Sqrt[3]/2;
r2=1/2-I Sqrt[3]/2;


SetDirectory[NotebookDirectory[]];
FPLO=TRASF[(Import["Repository/Finite_Part_A_LO.m"])]//.{Nc->3,Nf->5,Log[s/\[Mu]\[Mu]^2]->0};


SetDirectory[NotebookDirectory[]];
FPVNLO=TRASF[Import["Repository/Finite_Part_A_NLO_fin.m"]]//.{Nc->3,Nf->5,Log[s/\[Mu]\[Mu]^2]->0};


(*Considering W bosons*)
yW=(((Sqrt[1-4RW]-1)/(Sqrt[1-4RW]+1)//.RW->mW^2/mH^2)//.mW->80.385//.mH->125.09)
(*Considering Z bosons*)
yZ=(((Sqrt[1-4RZ]-1)/(Sqrt[1-4RZ]+1)//.RZ->mZ^2/mH^2)//.mZ->91.1876//.mH->125.09)


(* ::Text:: *)
(*The prescription for analytic continuation is*)
(*          y->y+I 0.*)
(*Evaluate the expressions using a GPL evaluator in the first value of y for m=mW, in the second value of y for m=mZ.*)


y=yW


y=yZ
